{
    "$graph": [
        {
            "class": "Workflow",
            "label": "merge and annotate svs with population allele freq and vep",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/coding_only"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/cohort_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/custom_clinvar_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/custom_gnomad_vcf"
                },
                {
                    "type": "boolean",
                    "id": "#main/estimate_sv_distance"
                },
                {
                    "type": "int",
                    "id": "#main/max_distance_to_merge"
                },
                {
                    "type": "int",
                    "id": "#main/minimum_sv_calls"
                },
                {
                    "type": "int",
                    "id": "#main/minimum_sv_size"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "boolean",
                    "id": "#main/same_strand"
                },
                {
                    "type": "boolean",
                    "id": "#main/same_type"
                },
                {
                    "type": "File",
                    "id": "#main/sv_db"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/vcfs"
                },
                {
                    "type": "string",
                    "id": "#main/vep_cache_dir"
                },
                {
                    "type": "string",
                    "doc": "genome assembly to use in vep. Examples: GRCh38 or GRCm38",
                    "id": "#main/vep_ensembl_assembly"
                },
                {
                    "type": "string",
                    "doc": "ensembl species - Must be present in the cache directory. Examples: homo_sapiens or mus_musculus",
                    "id": "#main/vep_ensembl_species"
                },
                {
                    "type": "string",
                    "doc": "ensembl version - Must be present in the cache directory. Example: 95",
                    "id": "#main/vep_ensembl_version"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [],
                    "id": "#main/vep_plugins"
                }
            ],
            "steps": [
                {
                    "run": "#add_sv_population_frequency.cwl",
                    "in": [
                        {
                            "source": "#main/cohort_name",
                            "id": "#main/add_population_frequency/cohort_name"
                        },
                        {
                            "source": "#main/sv_db",
                            "id": "#main/add_population_frequency/sv_db"
                        },
                        {
                            "source": "#main/merge_vcfs/merged_vcf",
                            "id": "#main/add_population_frequency/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_population_frequency/merged_annotated_vcf"
                    ],
                    "id": "#main/add_population_frequency"
                },
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#main/coding_only",
                            "id": "#main/annotate_variants/coding_only"
                        },
                        {
                            "source": "#main/custom_clinvar_vcf",
                            "id": "#main/annotate_variants/custom_clinvar_vcf"
                        },
                        {
                            "source": "#main/custom_gnomad_vcf",
                            "id": "#main/annotate_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#main/vep_ensembl_assembly",
                            "id": "#main/annotate_variants/ensembl_assembly"
                        },
                        {
                            "source": "#main/vep_ensembl_species",
                            "id": "#main/annotate_variants/ensembl_species"
                        },
                        {
                            "source": "#main/vep_ensembl_version",
                            "id": "#main/annotate_variants/ensembl_version"
                        },
                        {
                            "default": false,
                            "id": "#main/annotate_variants/everything"
                        },
                        {
                            "default": "per_gene",
                            "id": "#main/annotate_variants/pick"
                        },
                        {
                            "source": "#main/vep_plugins",
                            "id": "#main/annotate_variants/plugins"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/annotate_variants/reference"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#main/add_population_frequency/merged_annotated_vcf",
                            "id": "#main/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotate_variants/annotated_vcf",
                        "#main/annotate_variants/vep_summary"
                    ],
                    "id": "#main/annotate_variants"
                },
                {
                    "run": "#survivor.cwl",
                    "in": [
                        {
                            "source": "#main/cohort_name",
                            "id": "#main/merge_vcfs/cohort_name"
                        },
                        {
                            "source": "#main/estimate_sv_distance",
                            "id": "#main/merge_vcfs/estimate_sv_distance"
                        },
                        {
                            "source": "#main/max_distance_to_merge",
                            "id": "#main/merge_vcfs/max_distance_to_merge"
                        },
                        {
                            "source": "#main/minimum_sv_calls",
                            "id": "#main/merge_vcfs/minimum_sv_calls"
                        },
                        {
                            "source": "#main/minimum_sv_size",
                            "id": "#main/merge_vcfs/minimum_sv_size"
                        },
                        {
                            "source": "#main/same_strand",
                            "id": "#main/merge_vcfs/same_strand"
                        },
                        {
                            "source": "#main/same_type",
                            "id": "#main/merge_vcfs/same_type"
                        },
                        {
                            "source": "#main/vcfs",
                            "id": "#main/merge_vcfs/vcfs"
                        }
                    ],
                    "out": [
                        "#main/merge_vcfs/merged_vcf"
                    ],
                    "id": "#main/merge_vcfs"
                },
                {
                    "run": "#sort_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/sort_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/sort_vcf/sorted_vcf"
                    ],
                    "id": "#main/sort_vcf"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/sort_vcf/sorted_vcf",
                    "id": "#main/merged_annotated_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotate_variants/vep_summary",
                    "id": "#main/vep_summary"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "add population allele frequencies to a vcf",
            "arguments": [
                "/opt/hall-lab/python-2.7.15/bin/svtools",
                "afreq",
                "$(inputs.vcf)",
                {
                    "shellQuote": false,
                    "valueFrom": "|"
                },
                "/opt/hall-lab/python-2.7.15/bin/svtools",
                "vcftobedpe",
                "-i",
                "stdin",
                {
                    "shellQuote": false,
                    "valueFrom": "|"
                },
                "/opt/hall-lab/python-2.7.15/bin/svtools",
                "varlookup",
                "-d",
                "200",
                "-c",
                "POPFREQ",
                "-a",
                "stdin",
                "-b",
                "$(inputs.sv_db)",
                {
                    "shellQuote": false,
                    "valueFrom": "|"
                },
                "/opt/hall-lab/python-2.7.15/bin/svtools",
                "bedpetovcf"
            ],
            "stdout": "$(inputs.cohort_name)",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "halllab/svtools:v0.4.0-2dc7f91"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000,
                    "coresMin": 1
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged_annotated.vcf",
                    "id": "#add_sv_population_frequency.cwl/cohort_name"
                },
                {
                    "type": "File",
                    "doc": "bed file containing allele frequencies for a population",
                    "id": "#add_sv_population_frequency.cwl/sv_db"
                },
                {
                    "type": "File",
                    "doc": "vcf to add population allele frequencies to",
                    "id": "#add_sv_population_frequency.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#add_sv_population_frequency.cwl/merged_annotated_vcf",
                    "outputBinding": {
                        "glob": "$(inputs.cohort_name)"
                    }
                }
            ],
            "id": "#add_sv_population_frequency.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sort VCF",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/picard/picard.jar",
                "SortVcf"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/sorted.vcf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "SEQUENCE_DICTIONARY="
                    },
                    "id": "#sort_vcf.cwl/reference_dict"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "id": "#sort_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "sorted.vcf"
                    },
                    "id": "#sort_vcf.cwl/sorted_vcf"
                }
            ],
            "id": "#sort_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Run SURVIVOR to merge SV calls",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/survivor_merge_helper.sh"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/survivor-cwl:1.0.6.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000,
                    "coresMin": 1
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8
                    },
                    "default": "SURVIVOR-sv-merged.vcf",
                    "doc": "Used to generate the output file name",
                    "id": "#survivor.cwl/cohort_name"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 6,
                        "valueFrom": "${\n  if(inputs.estimate_sv_distance){\n    return \"1\";\n  } else {\n    return \"0\";\n  }\n}\n"
                    },
                    "doc": "Estimate distance based on the size of SV",
                    "id": "#survivor.cwl/estimate_sv_distance"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Maximum distance of variants to consider for merging",
                    "id": "#survivor.cwl/max_distance_to_merge"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Minimum number of sv calls needed to be merged",
                    "id": "#survivor.cwl/minimum_sv_calls"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 7
                    },
                    "doc": "Minimum size of SVs to merge",
                    "id": "#survivor.cwl/minimum_sv_size"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "${\n  if(inputs.same_strand){\n    return \"1\";\n  } else {\n    return \"0\";\n  }\n}\n"
                    },
                    "doc": "Require merged SVs to be on the same strand",
                    "id": "#survivor.cwl/same_strand"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 4,
                        "valueFrom": "${\n  if(inputs.same_type){\n    return \"1\";\n  } else {\n    return \"0\";\n  }\n}\n"
                    },
                    "doc": "Require merged SVs to be of the same type",
                    "id": "#survivor.cwl/same_type"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1,
                        "itemSeparator": ","
                    },
                    "doc": "Array of VCFs to merge SV calls of",
                    "id": "#survivor.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cohort_name)"
                    },
                    "id": "#survivor.cwl/merged_vcf"
                }
            ],
            "id": "#survivor.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 64000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.1.0"
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--fork",
                "4",
                "--term",
                "SO",
                "--transcript_version",
                "--offline",
                "--cache",
                "--symbol",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--dir",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.custom_clinvar_vcf) {\n        return [\"--custom\", inputs.custom_clinvar_vcf.path + \",clinvar,vcf,exact,0,CLINSIGN,PHENOTYPE,SCORE,RCVACC,TESTEDINGTR,PHENOTYPELIST,NUMSUBMIT,GUIDELINES\"]\n\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 7
                    },
                    "id": "#vep.cwl/custom_clinvar_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.custom_gnomad_vcf) {\n        return ['--check_existing', '--custom', inputs.custom_gnomad_vcf.path + ',gnomADe,vcf,exact,0,AF,AF_AFR,AF_AMR,AF_ASJ,AF_EAS,AF_FIN,AF_NFE,AF_OTH,AF_SAS']\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 6
                    },
                    "id": "#vep.cwl/custom_gnomad_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--assembly",
                        "position": 11
                    },
                    "doc": "genome assembly to use in vep. Examples: 'GRCh38' or 'GRCm38'",
                    "id": "#vep.cwl/ensembl_assembly"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--species",
                        "position": 13
                    },
                    "doc": "ensembl species - Must be present in the cache directory. Examples: 'homo_sapiens' or 'mus_musculus'",
                    "id": "#vep.cwl/ensembl_species"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--cache_version",
                        "position": 12
                    },
                    "doc": "ensembl version - Must be present in the cache directory. Example: '95'",
                    "id": "#vep.cwl/ensembl_version"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--everything",
                        "position": 10
                    },
                    "id": "#vep.cwl/everything"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vep.cwl/pick/pick",
                                "#vep.cwl/pick/flag_pick",
                                "#vep.cwl/pick/pick_allele",
                                "#vep.cwl/pick/per_gene",
                                "#vep.cwl/pick/pick_allele_gene",
                                "#vep.cwl/pick/flag_pick_allele",
                                "#vep.cwl/pick/flag_pick_allele_gene"
                            ]
                        }
                    ],
                    "default": "flag_pick",
                    "inputBinding": {
                        "prefix": "--",
                        "separate": false,
                        "position": 7
                    },
                    "id": "#vep.cwl/pick"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--plugin"
                        }
                    },
                    "inputBinding": {
                        "position": 9
                    },
                    "id": "#vep.cwl/plugins"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--fasta",
                        "position": 8
                    },
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
